==> haskell-cryptohash-cryptoapi-0.1.4-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-2dm3EcMNEsW3UybrzEoa3m
key: cryptohash-cryptoapi-0.1.4-2dm3EcMNEsW3UybrzEoa3m
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: e25cea22164bbd56671cc56c7468be7c
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-2dm3EcMNEsW3UybrzEoa3m
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    crypto-api-0.13.3-BkUbrvVpNfiChPu2ZO0fOd
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-ATv4Mt2c0fR8VQPhtDqwOZ
key: cryptohash-cryptoapi-0.1.4-ATv4Mt2c0fR8VQPhtDqwOZ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 6b51707deec1ea617fd2fa3cbaf80293
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-ATv4Mt2c0fR8VQPhtDqwOZ
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
